# WARNING: Please don't edit this file. It was generated by Python/WinRT v2.0.0-beta.2

import winrt.system
from winrt import _winrt_windows_phone_personalinformation_provisioning

__all__ = [
    "ContactPartnerProvisioningManager",
    "MessagePartnerProvisioningManager",
]

ContactPartnerProvisioningManager = _winrt_windows_phone_personalinformation_provisioning.ContactPartnerProvisioningManager
MessagePartnerProvisioningManager = _winrt_windows_phone_personalinformation_provisioning.MessagePartnerProvisioningManager
